Documentation
¶
Overview ¶
Provides helpers for authentication & authorization via HTTP. Outlet credentials are encrypted and signed in the authorization payload.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EncryptAndSign ¶
Use the first valid key to sign b. Returns error if no key is able to sign b.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.