Documentation
¶
Overview ¶
An internal metrics channel. l2met internal components can publish their metrics here and they will be outletted to Librato.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Channel ¶
type Channel struct {
// The time by which metchan will aggregate internal metrics.
FlushInterval time.Duration
// The Channel is thread-safe.
sync.Mutex
Enabled bool
Buffer map[string]*bucket.Bucket
// contains filtered or unexported fields
}
func New ¶
Returns an initialized Metchan Channel. Creates a new HTTP client for direct access to Librato. This channel is orthogonal with other librato http clients in l2met. If a blank URL is given, no metric posting attempt will be made. If verbose is set to true, the metric will be printed to STDOUT regardless of whether the metric is sent to Librato.
Click to show internal directories.
Click to hide internal directories.